@@ -1,5 +1,4 @@
 use bytes::Bytes;
-use std::convert::{TryFrom, TryInto};
 use std::error::Error;
 use std::fmt;
 
@@ -20,28 +19,39 @@ impl Error for HttpVersionError {}
 
 #[derive(Debug, PartialEq, Clone)]
 pub enum HttpVersion {
+    Http10,
     Http11,
 }
 
+impl HttpVersion {
+    #[inline]
+    pub fn major(&self) -> u8 {
+        match self {
+            HttpVersion::Http10 => 1,
+            HttpVersion::Http11 => 1,
+        }
+    }
+
+    #[inline]
+    pub fn minor(&self) -> u8 {
+        match self {
+            HttpVersion::Http10 => 0,
+            HttpVersion::Http11 => 1,
+        }
+    }
+}
+
 impl From<HttpVersion> for Bytes {
+    #[inline]
     fn from(v: HttpVersion) -> Self {
         match v {
-            HttpVersion::Http11 => Bytes::from_static(&[72u8, 84, 84, 80, 47, 49, 46, 49]),
-        }
-    }
-}
-
-impl TryFrom<[u8; 8]> for HttpVersion {
-    type Error = HttpVersionError;
-
-    fn try_from(v: [u8; 8]) -> Result<Self, Self::Error> {
-        match v {
-            [72, 84, 84, 80, 47, 49, 46, 49] => Ok(HttpVersion::Http11),
-            _ => Err(HttpVersionError::InvalidHttpVersion),
+            HttpVersion::Http10 => Bytes::from_static(b"HTTP/1.0"),
+            HttpVersion::Http11 => Bytes::from_static(b"HTTP/1.1"),
         }
     }
 }
 
+#[inline]
 pub fn get_http_version(v: &[u8]) -> Result<HttpVersion, HttpVersionError> {
     if v.len() != 8 {
         return Err(HttpVersionError::InvalidHttpVersion);
@@ -53,6 +63,7 @@ pub fn get_http_version(v: &[u8]) -> Result<HttpVersion, HttpVersionError> {
     let val = u64::from_be_bytes(buf);
 
     match val {
+        0x485454502f312e30 => Ok(HttpVersion::Http10),
         0x485454502f312e31 => Ok(HttpVersion::Http11),
         _ => Err(HttpVersionError::InvalidHttpVersion),
     }
